@@ -209,6 +209,7 @@ static void          clear_cache     (GConfSource* source);
 static void          blow_away_locks (const char *address);
 
 static GConfBackendVTable xml_vtable = {
+  sizeof (GConfBackendVTable),
   x_shutdown,
   resolve_address,
   lock,
@@ -227,7 +228,10 @@ static GConfBackendVTable xml_vtable = {
   sync_all,
   destroy_source,
   clear_cache,
-  blow_away_locks
+  blow_away_locks,
+  NULL, /* set_notify_func */
+  NULL, /* add_listener    */
+  NULL  /* remove_listener */
 };
 
 static void          
